Commit in GeomConverter/src/org/lcsim/detector/tracker/silicon on MAIN
SiStrips.java+1-11.14 -> 1.15
Better modeling of capacitance for strips.

GeomConverter/src/org/lcsim/detector/tracker/silicon
SiStrips.java 1.14 -> 1.15
diff -u -r1.14 -r1.15
--- SiStrips.java	24 Dec 2007 14:27:07 -0000	1.14
+++ SiStrips.java	6 Jun 2008 17:09:48 -0000	1.15
@@ -227,7 +227,7 @@
     
     public double getCapacitance(int cell_id) // capacitance in pF
     {
-        return 0.1*getStripLength(cell_id);  // FIXME: hard wired for now to 0.1 pf/mm
+        return 10+0.1*getStripLength(cell_id);  // FIXME: hard wired for now to 10+0.1 pf/mm
     }
     
     public SortedMap<Integer,Integer> computeElectrodeData(ChargeDistribution distribution)
CVSspam 0.2.8